You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@falcon.apache.org by sa...@apache.org on 2015/04/21 09:12:27 UTC

falcon git commit: FALCON-1131 Fixing FeedClusterUpdateTest and name confilcts in FALCON-1113 . Contributed by pragya m

Repository: falcon
Updated Branches:
  refs/heads/master 74ce00b1e -> df0c8d35a


FALCON-1131 Fixing FeedClusterUpdateTest and name confilcts in FALCON-1113 . Contributed by pragya m


Project: http://git-wip-us.apache.org/repos/asf/falcon/repo
Commit: http://git-wip-us.apache.org/repos/asf/falcon/commit/df0c8d35
Tree: http://git-wip-us.apache.org/repos/asf/falcon/tree/df0c8d35
Diff: http://git-wip-us.apache.org/repos/asf/falcon/diff/df0c8d35

Branch: refs/heads/master
Commit: df0c8d35a244c18ead634a938f80d42bcf08718a
Parents: 74ce00b
Author: samarthg <sa...@apacge.org>
Authored: Tue Apr 21 12:42:05 2015 +0530
Committer: samarthg <sa...@apacge.org>
Committed: Tue Apr 21 12:42:05 2015 +0530

----------------------------------------------------------------------
 falcon-regression/CHANGES.txt                   |  5 +++-
 .../falcon/regression/core/util/HadoopUtil.java | 12 +++++-----
 .../regression/FeedClusterUpdateTest.java       | 25 ++++++++++----------
 .../falcon/regression/prism/FeedDelayTest.java  |  2 +-
 4 files changed, 24 insertions(+), 20 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/falcon/blob/df0c8d35/falcon-regression/CHANGES.txt
----------------------------------------------------------------------
diff --git a/falcon-regression/CHANGES.txt b/falcon-regression/CHANGES.txt
index 8d5fd38..8ed2af9 100644
--- a/falcon-regression/CHANGES.txt
+++ b/falcon-regression/CHANGES.txt
@@ -63,7 +63,10 @@ Trunk (Unreleased)
    via Samarth Gupta)
 
   IMPROVEMENTS
-   
+  
+   FALCON-1131 Fixing FeedClusterUpdateTest and name confilcts in FALCON-1113(Pragya M 
+   via Samarth Gupta) 
+
    FALCON-1145 Changing entity name if it exceeds defined length(Pragya M via Samarth G)
 
    FALCON-1151 Migrate oozie related methods from InstanceUtil.java to OozieUtil.java

http://git-wip-us.apache.org/repos/asf/falcon/blob/df0c8d35/falcon-regression/merlin-core/src/main/java/org/apache/falcon/regression/core/util/HadoopUtil.java
----------------------------------------------------------------------
diff --git a/falcon-regression/merlin/src/test/java/org/apache/falcon/regression/FeedClusterUpdateTest.java b/falcon-regression/merlin/src/test/java/org/apache/falcon/regression/FeedClusterUpdateTest.java
index 2a9e205..feb0cc1 100644
--- a/falcon-regression/merlin/src/test/java/org/apache/falcon/regression/FeedClusterUpdateTest.java
+++ b/falcon-regression/merlin/src/test/java/org/apache/falcon/regression/FeedClusterUpdateTest.java
@@ -114,7 +114,7 @@ public class FeedClusterUpdateTest extends BaseTestClass {
         removeTestClassEntities();
     }
 
-    @Test(enabled = false, groups = {"multiCluster"})
+    @Test(enabled = true, groups = {"multiCluster"})
     public void addSourceCluster() throws Exception {
         //add one source and one target , schedule only on source
         feedOriginalSubmit = FeedMerlin.fromString(feed)
@@ -156,6 +156,7 @@ public class FeedClusterUpdateTest extends BaseTestClass {
                 .withRetention("hours(10)", ActionType.DELETE)
                 .withValidity(startTime, TimeUtil.addMinsToTime(startTime, 65))
                 .withClusterType(ClusterType.SOURCE)
+                .withPartition("UK/${cluster.colo}")
                 .build())
             .toString();
         feedUpdated = FeedMerlin.fromString(feedUpdated).addFeedCluster(
@@ -185,11 +186,11 @@ public class FeedClusterUpdateTest extends BaseTestClass {
         Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster2OC, feedName, "RETENTION"), 2);
         Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster3OC, feedName, "REPLICATION"), 0);
         Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster3OC, feedName, "RETENTION"), 1);
-        Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster1OC, feedName, "REPLICATION"), 1);
-        Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster1OC, feedName, "RETENTION"), 2);
+        Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster1OC, feedName, "REPLICATION"), 2);
+        Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster1OC, feedName, "RETENTION"), 1);
     }
 
-    @Test(enabled = false, groups = {"multiCluster"})
+    @Test(enabled = true, groups = {"multiCluster"})
     public void addTargetCluster() throws Exception {
         //add one source and one target , schedule only on source
         feedOriginalSubmit = FeedMerlin.fromString(feed)
@@ -268,9 +269,9 @@ public class FeedClusterUpdateTest extends BaseTestClass {
         Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster1OC, feedName, "RETENTION"), 1);
     }
 
-    @Test(enabled = false, groups = {"multiCluster"})
+    @Test(enabled = true, groups = {"multiCluster"})
     public void add2SourceCluster() throws Exception {
-        //add one source and one target , schedule only on source
+        //add one source , schedule only on source
         feedOriginalSubmit = FeedMerlin.fromString(feed)
             .addFeedCluster(new FeedMerlin.FeedClusterBuilder(cluster2Name)
                 .withRetention("hours(10)", ActionType.DELETE)
@@ -338,7 +339,7 @@ public class FeedClusterUpdateTest extends BaseTestClass {
         Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster1OC, feedName, "RETENTION"), 1);
     }
 
-    @Test(enabled = false, groups = {"multiCluster"})
+    @Test(enabled = true, groups = {"multiCluster"})
     public void add2TargetCluster() throws Exception {
         //add one source and one target , schedule only on source
         feedOriginalSubmit = FeedMerlin.fromString(feed)
@@ -406,7 +407,7 @@ public class FeedClusterUpdateTest extends BaseTestClass {
         Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster1OC, feedName, "RETENTION"), 1);
     }
 
-    @Test(enabled = false, groups = {"multiCluster"})
+    @Test(enabled = true, groups = {"multiCluster"})
     public void add1Source1TargetCluster() throws Exception {
         //add one source and one target , schedule only on source
         feedOriginalSubmit = FeedMerlin.fromString(feed)
@@ -476,7 +477,7 @@ public class FeedClusterUpdateTest extends BaseTestClass {
         Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster1OC, feedName, "RETENTION"), 1);
     }
 
-    @Test(enabled = false, groups = {"multiCluster"})
+    @Test(enabled = true, groups = {"multiCluster"})
     public void deleteSourceCluster() throws Exception {
         //add one source and one target , schedule only on source
         feedOriginalSubmit = FeedMerlin.fromString(feed)
@@ -551,8 +552,8 @@ public class FeedClusterUpdateTest extends BaseTestClass {
         Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster2OC, feedName, "RETENTION"), 2);
         Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster3OC, feedName, "REPLICATION"), 0);
         Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster3OC, feedName, "RETENTION"), 1);
-        Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster1OC, feedName, "REPLICATION"), 0);
-        Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster1OC, feedName, "RETENTION"), 0);
+        Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster1OC, feedName, "REPLICATION"), 3);
+        Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster1OC, feedName, "RETENTION"), 2);
     }
 
     @Test(enabled = true, groups = {"multiCluster"})
@@ -653,7 +654,7 @@ public class FeedClusterUpdateTest extends BaseTestClass {
         Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster2OC, feedName, "REPLICATION"), 0);
         Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster2OC, feedName, "RETENTION"), 1);
         Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster3OC, feedName, "REPLICATION"), 0);
-        Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster3OC, feedName, "RETENTION"), 2);
+        Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster3OC, feedName, "RETENTION"), 1);
         Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster1OC, feedName, "REPLICATION"), 2);
         Assert.assertEquals(OozieUtil.checkIfFeedCoordExist(cluster1OC, feedName, "RETENTION"), 1);
     }

http://git-wip-us.apache.org/repos/asf/falcon/blob/df0c8d35/falcon-regression/merlin/src/test/java/org/apache/falcon/regression/prism/FeedDelayTest.java
----------------------------------------------------------------------
diff --git a/falcon-regression/merlin/src/test/java/org/apache/falcon/regression/prism/FeedDelayTest.java b/falcon-regression/merlin/src/test/java/org/apache/falcon/regression/prism/FeedDelayTest.java
index 99f58e6..b9d9b97 100644
--- a/falcon-regression/merlin/src/test/java/org/apache/falcon/regression/prism/FeedDelayTest.java
+++ b/falcon-regression/merlin/src/test/java/org/apache/falcon/regression/prism/FeedDelayTest.java
@@ -191,7 +191,7 @@ public class FeedDelayTest extends BaseTestClass {
         //Adding data to empty folders
         for (String location : missingDependencies) {
             LOGGER.info("Transferring data to : " + location);
-            HadoopUtil.copyDataToFolder(sourceFS, location, OSUtil.RESOURCES + "feed-s4Replication.xml");
+            HadoopUtil.copyDataToFolder(sourceFS, location, OSUtil.RESOURCES + "dataFile.xml");
         }
         return missingDependencies;
     }
diff --git a/falcon-regression/merlin-core/src/main/java/org/apache/falcon/regression/core/util/HadoopUtil.java b/falcon-regression/merlin-core/src/main/java/org/apache/falcon/regression/core/util/HadoopUtil.java
index e2c3ae2..b91725c 100644
--- a/falcon-regression/merlin-core/src/main/java/org/apache/falcon/regression/core/util/HadoopUtil.java
+++ b/falcon-regression/merlin-core/src/main/java/org/apache/falcon/regression/core/util/HadoopUtil.java
@@ -431,7 +431,7 @@ public final class HadoopUtil {
     }
 
     /**
      * Uploads either _SUCCESS or log_01.txt file to remote directories with names within date
      * ranges.
      * @param fs target filesystem
      * @param interval dates ranges before and after current date
@@ -449,12 +449,12 @@ public final class HadoopUtil {
         if (fileToBePut.equals("_SUCCESS")) {
             copyDataToFolders(fs, folderPrefix, folderPaths, OSUtil.NORMAL_INPUT + "_SUCCESS");
         } else {
-            copyDataToFolders(fs, folderPrefix, folderPaths, OSUtil.NORMAL_INPUT + "log_01.txt");
+            copyDataToFolders(fs, folderPrefix, folderPaths, OSUtil.NORMAL_INPUT + "dataFile4.txt");
         }
     }
 
     /**
      * Uploads log_01.txt file to remote directories with names within date ranges.
      * @param fs target filesystem
      * @param interval dates ranges before and after current date
      * @param minuteSkip time to skip within a range to get intermediate directories
@@ -472,11 +472,11 @@ public final class HadoopUtil {
             }
         }
         createFolders(fs, folderPrefix, folderPaths);
-        copyDataToFolders(fs, folderPrefix, folderPaths, OSUtil.NORMAL_INPUT + "log_01.txt");
+        copyDataToFolders(fs, folderPrefix, folderPaths, OSUtil.NORMAL_INPUT + "dataFile4.txt");
     }
 
     /**
      * Uploads both log_01.txt and _SUCCESS files to remote directories with names within date
      * ranges.
      * @param fs target filesystem
      * @param interval dates ranges before and after current date
@@ -496,7 +496,7 @@ public final class HadoopUtil {
         }
         createFolders(fs, folderPrefix, folderPaths);
         copyDataToFolders(fs, folderPrefix, folderPaths,
-            OSUtil.NORMAL_INPUT + "_SUCCESS", OSUtil.NORMAL_INPUT + "log_01.txt");
+            OSUtil.NORMAL_INPUT + "_SUCCESS", OSUtil.NORMAL_INPUT + "dataFile4.txt");
     }
 
     /**

http://git-wip-us.apache.org/repos/asf/falcon/blob/df0c8d35/falcon-regression/merlin/src/test/java/org/apache/falcon/regression/FeedClusterUpdateTest.java
----------------------------------------------------------------------
@@ -431,7 +431,7 @@ public final class HadoopUtil {
 
     /**
-     * Uploads either _SUCCESS or log_01.txt file to remote directories with names within date
+     * Uploads either _SUCCESS or dataFile4.txt file to remote directories with names within date
      * ranges.
      * @param fs target filesystem
@@ -449,12 +449,12 @@ public final class HadoopUtil {
 
     /**
-     * Uploads log_01.txt file to remote directories with names within date ranges.
+     * Uploads dataFile4.txt file to remote directories with names within date ranges.
      * @param fs target filesystem
      * @param interval dates ranges before and after current date
@@ -472,11 +472,11 @@ public final class HadoopUtil {
 
     /**
-     * Uploads both log_01.txt and _SUCCESS files to remote directories with names within date
+     * Uploads both dataFile4.txt and _SUCCESS files to remote directories with names within date
      * ranges.
      * @param fs target filesystem